@@ -50,7 +50,11 @@ UpdateModel::UpdateModel(QObject *parent)
     connect(m_updateSizeTimer, &QTimer::timeout, this, &UpdateModel::updateSizeChanged);
 }
 
-UpdateModel::~UpdateModel() = default;
+UpdateModel::~UpdateModel()
+{
+    qDeleteAll(m_updateItems);
+    m_updateItems.clear();
+}
 
 QHash<int,QByteArray> UpdateModel::roleNames() const
 {
@@ -137,6 +141,7 @@ QVariant UpdateModel::data(const QModelIndex &index, int role) const
             case UpdateItem::ApplicationSection: return appUpdatesSection;
             case UpdateItem::SystemSection: return systemUpdateSection;
         }
+        return {};
     } 
     case SectionResourceProgressRole:
         return (100-item->progress()) + (101 * item->section());
