@@ -69,8 +69,9 @@ void PKTransaction::trigger(PackageKit::Transaction::TransactionFlags flags)
     if (m_apps.size() == 1 && qobject_cast<LocalFilePKResource*>(m_apps.at(0))) {
         auto app = qobject_cast<LocalFilePKResource*>(m_apps.at(0));
         m_trans = PackageKit::Daemon::installFile(QUrl(app->packageName()).toLocalFile(), flags);
-        connect(m_trans.data(), &PackageKit::Transaction::finished, this, [app](PackageKit::Transaction::Exit status) {
-            if (status == PackageKit::Transaction::ExitSuccess) {
+        connect(m_trans.data(), &PackageKit::Transaction::finished, this, [this, app](PackageKit::Transaction::Exit status) {
+			const bool simulate = m_trans->transactionFlags() & PackageKit::Transaction::TransactionFlagSimulate;
+            if (!simulate && status == PackageKit::Transaction::ExitSuccess) {
                 app->markInstalled();
             }
         });
